@@ -1,7 +1,9 @@
 #ifndef COMBOMANAGER_H
 #define COMBOMANAGER_H
 
-#include <assert.h>
+#include <cassert>
+
+using namespace std;
 
 #include "ComboTabulator.h"
 #include "BlockManager.h"
