@@ -1,6 +1,8 @@
 #ifndef CONTORLLER_H
 #define CONTORLLER_H
 
+using namespace std;
+
 #define CC_LEFT                     (1 << 0)
 #define CC_RIGHT                    (1 << 1)
 #define CC_UP                       (1 << 2)
@@ -17,6 +19,7 @@ public:
   static void specialPlay ( int key, int x, int y );
   static void specialUpPlay ( int key, int x, int y );
   static void keyboardMeta ( unsigned char key, int x, int y );
+  static void keyboardUpMeta ( unsigned char key, int x, int y );
   static void specialMeta ( int key, int x, int y );
   static void specialUpMeta ( int key, int x, int y );
   static void entry ( int mouse_state );
