@@ -25,6 +25,8 @@
  * Handle's the displaying of the garbage.
  */
 
+#define GL_GLEXT_LEGACY
+
 #include <GL/glut.h>
 
 #ifndef _WIN32
@@ -32,6 +34,8 @@
 #  include <glext.h>
 #endif
 
+using namespace std;
+
 #include "Game.h"
 #include "Block.h"
 #include "Creep.h"
