@@ -1,7 +1,9 @@
 #ifndef LOSEBAR_H
 #define LOSEBAR_H
 
-#include <assert.h>
+#include <cassert>
+
+using namespace std;
 
 #define LB_INACTIVE                  (1 << 0)
 #define LB_LOW_ALERT                 (1 << 1)
